# django-calcul

`django-calcul` est une application Django réutilisable qui permet d’effectuer des **opérations mathématiques simples** (addition, soustraction, multiplication, division) via une interface web ou en ligne de commande.

---

## 🚀 Fonctionnalités

- Interface web Django pour faire des calculs
- Ligne de commande `django-calcul` pour des calculs rapides dans le terminal
- App Django facilement intégrable dans n'importe quel projet
- Prend en charge Python 3.6+

---

## 📦 Installation

### 1. Installer le package (depuis un dépôt local ou PyPI)

```bash
pip install django-calcul
django-calcul add argument1 argument2 (pour la addition )
django-calcul sub argument1 argument2 (pour la soustraction )
django-calcul mul argument1 argument2 (pour la multiplication )
django-calcul div argument1 argument2 (pour la division )


